=====================================
Pyspark Gateway |Build Status| |PyPi|
=====================================

Connect to remote Pyspark clusters.

.. |Build Status| image:: https://travis-ci.org/abronte/PysparkGateway.svg?branch=master
   :target: https://travis-ci.org/abronte/PysparkGateway

.. |PyPi| image:: https://img.shields.io/pypi/v/pysparkgateway.svg
   :target: https://pypi.org/project/PysparkGateway/
